#
# spec file for package onedrive
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2018-2022 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_userunitdir: %{expand: %%global _userunitdir %{_unitdir}/../user}}
%define docdir %{_defaultdocdir}/%{name}

# DMD is available only on x86*. Use LDC otherwise.
%ifarch %{ix86} x86_64
%bcond_without dcompiler_dmd
%else
%bcond_with dcompiler_dmd
%endif

Name:           onedrive
Version:        2.5.5
Release:        1.1
Summary:        Client for One Drive Service for Linux
License:        GPL-3.0-only
Group:          Productivity/Networking/Other
URL:            https://github.com/abraunegg/onedrive/
Source0:        %{name}-%{version}.tar.xz
%if %{with dcompiler_dmd}
BuildRequires:  dmd >= 2.087.0
BuildRequires:  phobos-devel-static
%else
BuildRequires:  ldc >= 1.17.0
BuildRequires:  ldc-phobos-devel
%endif
BuildRequires:  help2man
BuildRequires:  libcurl-devel
BuildRequires:  libnotify-devel
BuildRequires:  sqlite3-devel
Requires:       libnotify4
Recommends:     logrotate
Suggests:       onedrive-completition-bash
Suggests:       onedrive-completition-zsh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%package completion-bash
Summary:        OneDrive Bash completition
Group:          Productivity/Networking/Other
BuildRequires:  bash
BuildRequires:  bash-completion
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       bash
Requires:       bash-completion
Requires:       onedrive = %{version}
Supplements:    (%{name} and bash-completion)

%package completion-zsh
Summary:        OneDrive zsh completition
Group:          Productivity/Networking/Other
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)

%package completion-fish
Summary:        OneDrive fish completition
Group:          Productivity/Networking/Other
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)

%description
OneDrive is a client for Microsoft file serving service

%description completion-bash
OneDrive shell completions for Bash.

%description completion-zsh
OneDrive shell completions for zsh.

%description completion-fish
OneDrive shell completions for fish.

%prep
%setup -q
#sed -i /chown/d Makefile
sed -i 's/^docdir.*/docdir = @docdir@/g' Makefile.in

%build
%configure \
    --docdir=%{docdir} \
    --with-systemduserunitdir=%_userunitdir \
    --with-systemdsystemunitdir=%_unitdir \
    --enable-notifications \
    --enable-completions \
    --with-bash-completion-dir=/usr/share/bash-completion/completions/
make %{?_smp_mflags} %{name}

%install
%make_install
install -D -m 0644 config %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -d -m 0755 %{buildroot}%{_localstatedir}/log/%{name}
rm %{buildroot}%{_docdir}/%{name}/LICENSE

%pre
%service_add_pre %{name}@.service
%service_add_pre %{name}.service

%post
%service_add_post %{name}@.service
%service_add_post %{name}.service

%preun
%service_del_preun %{name}@.service
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}@.service
%service_del_postun %{name}.service

%files
%license LICENSE
%doc readme.md changelog.md
%config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_bindir}/%{name}
%dir %{_userunitdir}
%{_userunitdir}/%{name}.service
%{_unitdir}/%{name}@.service
%attr(0644, root, root) %{_mandir}/man1/%{name}.1*
%{_localstatedir}/log/%{name}
%dir %{_docdir}/%{name}
%{_docdir}/%{name}

%files completion-bash
%{_datadir}/bash-completion/completions/

%files completion-zsh
%dir %{_prefix}/local/share/zsh/
%dir %{_prefix}/local/share/zsh/site-functions
%{_prefix}/local/share/zsh/site-functions/_onedrive

%files completion-fish
%dir %{_prefix}/local/share/fish
%dir %{_prefix}/local/share/fish/completions
%{_prefix}/local/share/fish/completions/onedrive.fish

%changelog
* Mon Mar 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.5.5:
  * Feature Requests | Enhancements
  - Implement Feature Request: Implement 'disable_permission_set'
    configuration option to not set directory and file
    permissions (#3112)
  - Implement Feature Request: Implement 'write_xattr_data'
    configuration option to add information about file
    creator/last editor as extended file attributes (#3113)
  - Implement Feature Request: Implement 'transfer_order'
    configuration option to allow the user to determine what
    order files are transferred in (#3114)
  - Enhancement: Add support for --share-password option when
  - -create-share-link is called (#3119)
  - Enhancement: Add support 'localizedMessage' error messages in
    application output if this is provided in the JSON response
    from Microsoft Graph API (#3153)
  * Microsoft API Changes for OneDrive Personal Accounts
  - Comprehensively overhauled how OneDrive Personal Shared
    Folders are handled due to major OneDrive API backend
    platform user migration and major differences in API response
    output (#3116)
  - Comprehensively changed OneDrive Personal 'driveId' value
    checking due to major OneDrive API backend platform user
    migration and major differences in API response output
    (#3116)
  * Bug Fixes
  - Fix Bug: Fix path calculation for Client Side Filtering
    evaluations for Business Accounts (#3106)
  - Fix Bug: Fix path calculation for Client Side Filtering
    evaluations for Personal Accounts (#3111)
  - Fix Bug: Only perform path calculation if this is actually
    required
  - Fix Bug: Fix check for 'globbing' and 'wildcard' rules, that
    the number of segments before the first wildcard character
    need to match before the actual rule can be applied (#3123)
  - Fix Bug: When using 'sync_list', ignore specific exclusion to
    scan that path for new data, which may be actually included
    by an include rule, but the parent path is excluded (#3130)
  - Fix Bug: When removing a OneDrive Personal Shared Folder,
    remove the actual link, not the remote user folder (#3147)
  - Fix Bug: Fix 'Unsupported platform' for inotify watches by
    using the correct predefined version definition for Linux.
    (#3152)
  * Other Changes | Fixes
  - Changed curl debug logging to --debug-https as this is more
    relevant (#3120)
  - Updated Fedora Docker OS version to Fedora 41 (#3150)
  - Updated Alpine Docker OS version to Alpine 3.21 (#3150)
  - Updated documentation
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.5.4:
  * Release files for 2.5.4 (#3098)
  * Add './' sync_list rule check (#3097)
  * Fix log output when generating a /delta response
  * Add code to support 'display_processing_time' use (#3095)
  * Calculate file transfer metrics in a consistent manner (#3091)
  * Fix testInternetReachability function (#3087)
  * Update usage.md (#3084)
  * Add OneDrive Personal Drive ID and Remote Drive ID length check
    (#3086)
  * Fix --single-directory Shared Folder DB entry creation (#3082)
  * Support the moving of Shared Folder Links to other folders
    (#3052)
  * Fix Upload|Download Loop for AIP Protected File in Monitor Mode
    (#3071)
  * Add account root id check for Microsoft OneDrive Personal
    account issue (#3077)
  * Update install.md
  * Update install.md
  * Change dynamic linker to Linux only to correctly support
    FreeBSD and OpenBSD (#3069)
  * Fix Alpine Docker build post FreeBSD support (#3068)
  * Support FreeBSD - Code and documentation changes to support
    FreeBSD (#3048)
  * Fix issue #3057 where timestamp is not set when using
  - -disable-download-validation (#3064)
  * Support adding SharePoint Libraries as Shared Folder Links
    (#3051)
  * Fix that the root Personal Shared Folder is not handled due to
    missing API data (#3047)
  * Fix that item deleted after events of IN_MOVED_FROM &
    IN_CLOSE_WRITE (#3045)
  * Fix moving online files inside directories when using
    'sync_list' (#3042)
  * Fix skip_dir logic when reverse traversing folder structure
    (#3034)
  * Fix regression in handling uploading new and modified content
    to OneDrive Business and SharePoint (#3032)
  * Update Arch Linux instructions (#3036)
  * Fix regression of --display-config use (#3035)
  * correct minor typo (#3033)
  * Update docker.md (#3028)
  * Update --dry-run authentication message (#3022)
  * Update .gitignore
  * Update isValidUTF8 function with further validation (#3016)
  * feat: optionally use standalone mode for syncing using Docker
    container (#3018)
  * Fix download error of an updated file leads to online file
    deletion (#3017)
  * Check for no --sync | --monitor earlier to fail fast if not
    used (#3011)
  * Implement Feature Request: Support Permanent Delete on OneDrive
    (#2999)
  * Add quota status messages based on OneDrive Account API
    response (#3008)
  * Cleanup debug logging output (#3007)
  * Fix regression that sync_list does not traverse shared
    directories (#3004)
  * Fix that Business Shared Items shortcuts are skipped (#3001)
  * Fix --display-config when dealing with empty sync_list (#2998)
  * Fix import of 'sync_list' and rule application (#2996)
  * Update usage.md
  * Update usage.md (#2990)
  * Add curl bugs to documentation (#2987)
  * Fix unable to parse SSL version (#2981)
  * Fix build error on OpenBSD (#2978)
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.3:
  * Feature Requests | Enhancements
  - Enhancement: Ensure application notifies user of curl
    versions that contain HTTP/2 bugs that impact the operation
    of this client (#2913, #2922, #2926)
  - Enhancement: Update Dockerfile-debian to fix that libcurl4
    does not get applied despite being pulled in. Explicitly
    install it from Debian 12 Backports
  - Enhancement: Add passive database checkpoints (#2944)
  - Enhancement: Add OpenSSL version warning (#2961)
  - Update safeBackup to use a new filename format for easier
    identification:
    filename-hostname-safeBackup-number.file_extension (#2966)
  * Bug Fixes
  - Fix Bug: Fix application crash when session upload files
    contain zero data or are corrupt (#2893)
  - Fix Bug: Fix that when creating a new folder online the
    application generates an exception if it is in a Shared
    Online Folder (#2895)
  - Fix Bug: Fix that a 'sync_list' entry of '/' will cause a
    index [0] is out of bounds (#2897)
  - Fix Bug: Fix regression for Docker 'sync_dir' use (#2901)
  - Fix Bug: Fix that curl generates a SIGPIPE that causes
    application to exit due to upstream device killing idle TCP
    connection (#2906)
  - Fix Bug: Fix that skip_file in config does not override
    defaults (#2917)
  - Fix Bug: Fix that skip_dir is not flagging directories
    correctly causing deletion if parental path structure needs
    to be created for sync_list handling (#2918)
  - Fix Bug: Fix application crash caused by unable to drop table
    (#2919)
  - Fix Bug: Setup a specific SIGPIPE Signal handler for
    curl/openssl generated signals (#2929)
  - Fix Bug: Handle DB upgrades from v2.4.x without causing
    application crash (#2932)
  - Fix Bug: Fix a database statement execution error occurred:
    NOT NULL constraint failed: item.type due to Microsoft
    OneNote items (#2939)
  - Fix Bug: Allow no-sync operations to complete online account
    checks (#2943)
  - Fix Bug: Update Dockerfile-alpine - revert to Alpine 3.19 as
    application fails to run on Alpine 3.20 (#2956)
  - Fix Bug: Fix Operation not permitted FileException Error when
    attempting to use setTimes() function (#2958)
  - Fix Bug: Fix that files with no mime type cause sync to crash
    (#2963)
  - Fix Bug: Ensure bypass_data_preservation operates as intended
    (#2967)
  * Other Changes | Fixes
  - Implement Docker ENV variable for --cleanup-local-files
    (#2868)
  - Improve performance with reduced execution time and lower
    CPU/system resource usage (#2880)
  - Specifically use a 'mutex' to perform the lock on DB actions
    (#2882)
  - Add Ubuntu 24.10 OpenSuSE Build Service details (#2942)
  - Add Check Spelling GitHub Action (#2945)
  - Updated documentation
* Sun Sep 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.2:
  * Feature Requests
  - Enhancement: Added 15 second sleep to systemd services to
    allow d-bus daemon to start and be available if present
    (#2762)
  * Bug Fixes
  - Fix Bug: Application crash unable to correctly process a
    timestamp that has fractional seconds (#2852)
  - Fix Bug: Fixed application logging output of Personal Shared
    Folder incorrectly advising there is no free space
  * Other Changes | Fixes
  - Updated documentation
* Sun Sep 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.1:
  DO NOT USE .. CONTAINS A MAJOR TIMESTAMP ISSUE BUG
  * Feature Requests
  - Enhancement: Add --enable-debug to Docker files when building
    client application (#2811)
  - Enhancement: Update Debian Dockerfile to use 'curl' from
    backports so a more modern curl version is used (#2831)
  - Enhancement: Don't print the d-bus WARNING if
    disable_notifications is set on cmd line or in config (#2840)
  * Bug Fixes
  - Fix Regression of extra quotation marks when using
    ONEDRIVE_SINGLE_DIRECTORY with Docker (#2823)
  - Fix Regression that --remove-source-files doesn’t work
    (#2830)
  - Fix Regression that real-time synchronization is not
    occurring when using --monitor and sync_list (#2832)
  - Fix Bug: Application crash when run synchronize due to
    negative free space online (#2806)
  - Fix Bug: Application crash when attempting to read timestamp
    from database as invalid data was written (#2810, #2813,
  [#2822], #2829)
  - Fix Bug: Application crash when performing a URL dedocde
    (#2815)
  - Fix Bug: Application crash when using sync_list and Personal
    Shared Folders the root folder fails to present the item id
    (#2835)
  * Other Changes | Fixes
  - Updated documentation (various)
* Tue Sep 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.0:
  * Important
  - OneDrive Client for Linux v2.5.0 contains a database schema
    change to support the additional functionality and bug fixes
    in the v2.5.x branch. As such, on your first use of this
    client version, the database schema will be updated and the
    client will perform an entire re-validation of your data -
    both locally and online which may take an extended period of
    time.
  * Caution
  - OneDrive Client for Linux v2.5.0 introduces significant
    changes and is not backwards compatible with v2.4.x. Please
    ensure that you do not use both v2.5.0 and v2.4.x clients
    with the same Microsoft OneDrive account simultaneously -
    whether on the same or different systems. If you upgrade to
    v2.5.0, all your clients must be updated to this version.
    However, you can revert to v2.4.x at any time if necessary,
    but do not run different versions at the same time on any
    system.
  * Caution
  - The application has been completely re-written in version
    2.5.0, leading to changes in how many features and functions
    operate compared to version 2.4.x. OneDrive Business Shared
    Folder Sync is one of the features that has been fully
    revamped. If you are using this feature, it is crucial to
    read the updated documentation thoroughly.
  - Additionally, when using the --download-only function, this
    no longer automatically deletes local files by default.
    Please ensure you review the new documentation carefully to
    understand how all application options now operate as there
    may be both major and subtle changes to the options that you
    currently utilise.
  * Feature Requests
  - Implement Feature Request: Multi-threaded
    uploading/downloading of files FR-232
  - Implement Feature Request: Renaming/Relocation of OneDrive
    Business shared folders FR-1251
  - Implement Feature Request: Support the syncing of individual
    business shared files FR-1300
  - Implement Feature Request: Implement application output to
    detail upload|download failures at the end of a sync process
    FR-2457
  - Implement Feature Request: Log when manual Authorization is
    required when using --auth-files FR-2475
  - Implement Feature Request: Add cmdline parameter to display
    (human readable) quota status FR-2359
  - Implement Feature Request: Add capability to disable
    'fullscan_frequency' FR-2313
  - Implement Feature Request: Ability to set
  - -disable-download-validation from Docker environment
    variable FR-2559
  - Implement Feature Request: Ability to set --sync-shared-files
    from Docker environment variable FR-2680
  - Implement Feature Request: file sync (upload/download/delete)
    notifications FR-2760
  * Bug Fixes
  - Fix Bug: Upload only not working with Business shared folders
    BUG-2379
  - Fix Bug: Business shared folders with same basename get
    merged BUG-2434
  - Fix Bug: --dry-run prevents authorization BUG-2451
  - Fix Bug: Log timestamps lacking trailing zeros, leading to
    poor log file output alignment BUG-2479
  - Fix Bug: Subscription ID already exists when using webhooks
    BUG-2501
  - Fix Bug: Not all files being downloaded when API data
    includes HTML ASCII Control Sequences BUG-2562
  - Fix Bug: --display-sync-status does not work when OneNote
    sections (.one files) are in your OneDrive. BUG-2578
  - Fix Bug: vim backups when editing files cause edited file to
    be deleted rather than the edited file being uploaded
    BUG-2586
  - Fix Bug: skip_dir does not always work as intended for all
    directory entries BUG-2590
  - Fix Bug: Online date being changed in download-only mode
    BUG-2591
  - Fix Bug: Resolve that download_only = "true" and
    cleanup_local_files = "true" also deletes files present
    online BUG-2612
  - Fix Bug: Resolve that upload session are not canceled with
    resync option BUG-2624
  - Fix Bug: Local files should be safely backed up when the item
    is not in sync locally to prevent data loss when they are
    deleted online BUG-2625
  - Fix Bug: Files with newer timestamp are not chosen as version
    to be kept BUG-2626
  - Fix Bug: Synced file is removed when updated on the remote
    while being processed by onedrive BUG-2699
  - Fix Bug: Cannot select/filter within Personal Shared Folders
    BUG-2731
  - Fix Bug: HTML encoding requires to add filter entries twice
    BUG-2740
  - Fix Bug: Uploading files using fragments stuck at 0%% BUG-2747
  - Fix Bug: Implement safeguard when sync_dir is missing and is
    re-created data is not deleted online BUG-2755
  - Fix Bug: Fix that --get-sharepoint-drive-id does not handle a
    SharePoint site with more than 200 entries BUG-2771
  - Fix Bug: Fix that 'sync_list' does not include files that
    should be included, when specified just as *.ext_type
    BUG-2784
  - Fix Bug: Fix that 'sync_list' does not allow to exclude
    '.folder_name' and include 'folder_name' BUG-2796
  * Other Changes | Fixes
  - Implement buffered logging so that all logging from all
    upload & download activities are handled correctly
  - Replace polling monitor loop with blocking wait
  - Update how the application utilises curl to fix socket reuse
  - Various performance enhancements with many thanks to @JC-comp
  - Implement refactored OneDrive API logic with many thanks to
    @JC-comp
  - Enforcement of operational conflicts
  - Enforcement of application configuration defaults and
    minimums
  - Utilise threadsafe sqlite DB access methods
  - Various code cleanup and optimisations
  * Documentation
  - Most documentation has been totally overhauled
* Thu Jun 22 2023 hpj@urpla.net
- Update to version 2.4.25:
  * Release files for 2.4.25 (#2440)
  * Fix that zero-byte files do not have a hash as reported by the OneDrive API thus should not generate an error message (#2436)
  * Update Docker files June 2023 (#2438)
  * Update testbuild.yaml (#2439)
  * Add Ubuntu 23.04 Instructions (#2437)
  * Update util.d (#2428)
  * Release files for 2.4.24 v2 (#2427)
  * Revert "Release files for 2.4.24 (#2426)"
  * Release files for 2.4.24 (#2426)
  * Implement #2414 to allow HTTP session timeout(s) tuning via config (#2425)
  * Remove sha1 use and cleanup defunct remaining crc32 use (#2424)
  * Update INSTALL.md
  * Update INSTALL.md (#2421)
  * Update ubuntu-package-install.md
  * Update ubuntu-package-install.md
  * Update Docker.md (#2409)
  * Update ubuntu-package-install.md (#2405)
  * Update INSTALL.md (#2403)
  * Fix Unable to perform a database vacuum: out of memory when exiting (#2398)
  * Update README.md (#2393)
  * Update Docker gosu version to 1.16 to resolve current vulnerabilities (#2386)
  * Update to Fedora Docker file to use Fedora 37 to resolve current vulnerabilities (#2383)
  * Update to Alpine Docker file to resolve current vulnerabilities (#2384)
  * Update to Debian Docker file to resolve current vulnerabilities (#2385)
  * Update USAGE.md (#2382)
  * Update USAGE.md (#2374)
  * Update ubuntu-package-install.md
  * Update Docker and Podman documents and clarify i386|i686 support (#2370)
  * Update Docker.md
  * Fix deprecation warnings with dmd 2.103.0 (#2364)
  * Add warning regarding SharePoint Library use (#2354)
  * Update testbuild.yaml (#2356)
  * Fix that folders are renamed despite using --dry-run (#2343)
  * Update USAGE.md
  * Fix that a HTTP 504 - Gateway Timeout causes local files to be deleted when using --download-only & --cleanup-local-files mode (#2342)
  * Fix webhook subscription creation for SharePoint Libraries (#2339)
  * Fix for extra encoded quotation marks surrounding Docker environment variables (#2319)
  * Update INSTALL.md (#2333)
  * Update USAGE.md (#2331)
  * Add --get-file-link option to shell completions  (#2308)
  * Update Docker.md (#2321)
  * Update Docker documentation to support locales for for double-byte language support (#2317)
  * Add single directory sync to docker (#2309)
  * Podman: Fix test volume is used (#2297)
  * Release 2.5.0 Development Prep (#2281)
* Fri Jan  6 2023 hpj@urpla.net
- Update to version 2.4.23:
  * Release files for 2.4.23 (#2280)
  * Update handling of --source-directory and --destination-directory if empty (#2278)
  * Update Alpine Dockerfile to use Alpine 3.17 (#2277)
  * Update USAGE.md
  * Update application-security.md
  * docs: Fix typos in Docker.md (#2270)
  * Update version checks (#2269)
  * Update version release notification handling (#2267)
  * Update --get-O365-drive-id error handling (#2266)
  * systemd: disable PrivateUsers (#2265)
  * Update INSTALL.md
  * Update RHEL7, RHEL8 and RHEL9 Makefile and SPEC file compatibility (#2256)
  * Restore RHEL7 spec file compatibility (#2254)
* Mon Dec  5 2022 hpj@urpla.net
- Update to version 2.4.22:
  * Release files for 2.4.22 (#2247)
  * Fix creation of parent empty directories when parent is excluded by sync_list (#2245)
  * Update config change detection handling (#2246)
  * Fix application crash when exiting due to failure state (#2244)
  * Change order of Microsoft OneDrive restrictions and limitations check and skip_file|skip_dir (#2238)
  * Update when application exit message is printed (#2239)
  * Display 'Sync with OneDrive is complete' when using --synchronize (#2229)
  * Fix application crash due to access permissions on configured path for sync_dir (#2225)
  * Fix issue of silent exit when unable to delete local files when using --cleanup-local-files (#2227)
  * Fix build error with LDC 1.28.1 on Alpine (#2220)
  * Fix build error with dmd-2.101.0 (#2219)
  * Update USAGE.md
  * Only call isPathExcludedViaSyncList if 'sync_list' is enabled where possible (#2213)
  * Ensure path does not start with '/' before sync_list check (#2215)
  * Update Fix 2211 and 2212 (#2214)
  * Update Docker.md
  * systemd: disable non-working remaining sandboxing options (#2205)
  * Only calculate path with computeItemPath if path is empty (#2212)
  * Fix application crash when local file is changed to a symbolic link with non-existent target  (#2211)
  * Update USAGE.md
  * Update USAGE.md
  * Update ubuntu-package-install.md
  * Add instructions for using OBS for Ubuntu 22.10 (#2201)
  * Add note regarding what application version should be used (#2200)
  * Add performance output for key functions (#2180)
  * Update USAGE.md (#2178)
  * Update podman.md (#2176)
  * owed -> owned (typo) (#2171)
  * Align application logging events to actual application defaults (#2170)
  * Remove Fedora ARMv7 builds (#2165)
  * Update docker.yaml to downgrade setup-qemu-action to use qemu-v6.2.0-26 (#2162)
  * Release 2.4.22 Dev Prep (#2161)
  * Update docker.yaml
* Mon Sep 26 2022 hpj@urpla.net
- Update to version 2.4.21:
  * Release files for 2.4.21 (#2157)
  * Update INSTALL.md
  * Add option to create a read-write shareable link (#2154)
  * Fix DMD 2.100.2 depreciation warning (#2156)
  * Update database access exclusivity test for --resync (#2155)
  * Update notification handling for specific skipped scenarios (#2153)
  * Update national-cloud-deployments.md (#2152)
  * Minor update to rpm build docs to match versions (#2146)
  * Update onedrive.spec.in to fix error building RPM (#2145)
  * Update ubuntu-package-install.md
  * Update documentation to document skip_size (#2132)
  * Add option to cleanup local files regardless of sync state when using --download-only (#2113)
  * Resolve segfault when running 'onedrive --display-sync-status' when run as 2nd process (#2105)
  * Fix where --resync is enforced for non-sync operations (#2111)
  * Fix to allow non-sync tasks while sync is running (#2112)
  * Update Docker and Podman documentation (#2109)
  * Improve application logging output for error messages (#2100)
  * Correct a typo in docs/INSTALL.md (#2097)
  * Update INSTALL.md (#2095)
  * Change the exit code of the application when a --resync is required (#2096)
  * Fix that logging output for skipped uploaded files is missing (#2094)
  * Update INSTALL.md
  * Update application-security.md and USAGE.md (#2088)
  * Update Podman.md to align to Docker.md
  * Update INSTALL.md
  * Update documentation in relation to configuring SharePoint Libraries (#2084)
  * Update what application options require an argument (#2082)
  * Add option to request readonly access in oauth authorization step (#2065)
  * Implement --display-running-config (#2064)
  * Update --get-O365-drive-id implementation for data access (#2076)
  * Update README.md
  * Be consistent with permissions that are being assigned (#2075)
  * Add Test Build Workflow (#2069)
  * Update --resync handling of database file removal (#2067)
  * Fix that the download progress bar doesn't always reach 100%% when rate_limit is set (#2056)
  * Release 2.4.21 Dev Prep (#2058)
* Tue Aug 16 2022 egotthold@suse.com
- Update to version 2.4.20:
  * Release files for 2.4.20 (#2052)
  * Enforce that --confdir must be a directory (#2051)
  * Increase thread sleep for better process handling (#2046)
  * Update Docker.md
  * Ensure that any active http instance is shutdown before any application exit (#2035)
  * Update USAGE.md (#2033)
  * Update USAGE.md
  * Fix handling of a custom configuration directory (#2029)
  * Fix --display-config after http/2 change (#2028)
  * Various little spelling fixes (check with lintian during Debian packaging) (#2027)
  * Switch to using curl defaults for HTTP/2 operations (#2026)
  * Update OneDrive API response handling for National Cloud Deployments (#2023)
  * Fix 'foreign key constraint failed' when using OneDrive Business Shared Folders (#2017)
  * Update known-issues.md (#2016)
  * Release 2.4.20 Dev Prep (#2013)
* Sat Jun 18 2022 hpj@urpla.net
- Update to version 2.4.19:
  * Release files for 2.4.19 (#2006)
  * Update when DB is updated by OneDrive API data and update when file hash is required to be generated (#2004)
  * Added ONEDRIVE_UPLOADONLY flag for Docker (#2002)
  * Update advanced-usage.md (#1999)
  * Documentation updates
  * Update README.md
  * Update src/notifications/README (#1992)
  * Update ubuntu-package-install.md
  * Update ubuntu-package-install.md (#1990)
  * Update lock.yml
  * Update Business Shared Folders to use a /delta query (#1989)
  * Update lock.yml
  * Update Docker.md
  * Update Docker Builds (#1988)
  * Update ubuntu-package-install.md
  * Update Documentation (#1985)
  * Update docker.yaml (#1984)
  * Trigger Docker build workflow only on pull request merge to 'master' (#1983)
  * Release 2.4.19 Dev Prep (#1981)
* Tue Jun  7 2022 Enno Gotthold <egotthold@suse.com>
- Update to version 2.4.18:
  * Fixed various database related access issues steming from running multiple instances of the application at the same time using the same configuration data (#1944, #1955)
  * Updated all Docker build files to current distributions, using updated distribution LDC version (#1945,#1972,#1975,#1976)
  * Updated logging output to logfiles when an actual sync process is occuring (#1947)
  * Fixed --display-config being impacted by --resync flag (#1950)
  * Fixed installation permissions for onedrive man-pages file (#1953)
  * Updated output of --display-config to be more relevant (#1956)
  * Fixed that in some situations that users try --upload-only and --download-only together which is not possible (#1959)
  * Added Feature Request to add an override for skip_dir|skip_file through flag to force sync (#1960)
  * Updated manpage to align with application configuration (#1962)
  * Fixed application crash if unable to read required hash files (#1963)
  * Added a check to validate local filesystem available space before attempting file download (#1971)
  * Updated documentation and Docker files based on minimum compiler versions to dmd-2.088.0 and ldc-1.18.0 (#1972)
  * Added GitHub Actions to build Docker containers and push to DockerHub (#1977)
  * Updated documentation (various)
* Wed May  4 2022 egotthold@suse.com
- Update to version 2.4.17:
  * Release files for 2.4.17 (#1941)
  * Update ubuntu-package-install.md (#1940)
  * Fix logging output when download failed (#1894)
  * Improve when the local database integrity check is performed and on what frequency (#1938)
  * Remove ambiguity on how to access 'help' for the client (#1936)
  * Update INSTALL.md
  * Update local folder creation timestamp with timestamp from OneDrive (#1934)
  * Update inotify logging output (#1930)
  * Update Internet connect disruption retry handling (#1909)
  * Update INSTALL.md
  * Fix crash when trying to sync broken symbolic link (#1917)
  * Update ubuntu-package-install.md
  * Update USAGE.md
  * Update ubuntu-package-install.md
  * Update bug_report.yml
  * Update INSTALL.md
  * Fix docker build, by add missing git (#1895)
  * Update README.md
* Thu Mar 10 2022 hpj@urpla.net
- Update to version 2.4.16:
  * Release files for 2.4.16 (#1879)
  * Add documentation for Podman support (#1871)
  * Update bug_report.yml (#1877)
  * Implement feature request to mark partially-downloaded files as .partial (#1868)
  * Implement feature request --modified-by (#1869)
  * Update YAML forms (#1875)
  * Use GitHub YAML forms (#1873)
  * Update USAGE.md
  * Add --reauth to allow easy re-authentication of the client (#1867)
  * Enhance error handling of GitHub version check (#1866)
  * Improved Dockerfiles (#1795)
  * Extend GitHub version check (#1863)
  * Add function to check client version vs latest GitHub release (#1862)
  * Update ubuntu-package-install.md
  * Catch errors from OneDrive when initialising subscriptions (#1846)
  * Update Docker.md (#1841)
  * Update entrypoint.sh (#1861)
  * Add config.yml to configure issue templates (#1845)
  * Update README.md (#1838)
  * Fix typo in the Ubuntu installation docs (#1830)
  * Update USAGE.md (#1829)
  * Split children query into a separate function which can be self-referred (#1828)
  * Fixes in order to compile on an Android host (#1823)
  * If a sync_list exclusion is matched, the item needs to be excluded when using --resync (#1820)
  * Document risk regarding using --resync (#1816)
  * Enable GitHub Sponsors (#1811)
  * Update ubuntu-package-install.md (#1807)
  * Update advanced-usage.md (#1806)
  * Update build-rpm-howto.md (#1799)
  * Update ubuntu-package-install.md (#1794)
  * Explicitly set libcurl options (#1789)
  * Update ubuntu-package-install.md (#1786)
  * Update application file logging error handling (#1776)
  * Update Ubuntu Docs (#1769)
  * Release 2.4.16 Dev Prep (#1768)
* Thu Jan 20 2022 Boris Manojlovic <boris@steki.net>
- rebuild manually tar file to pass Factory legal reqs...
* Thu Jan 20 2022 boris@steki.net
- Update to version 2.4.15:
  * Release files for 2.4.15 (#1767)
  * Update fixing edge case with OneDrive Personal Shared Folders and --resync --upload-only (#1762)
  * Add --operation-timeout argument (#1759)
  * Updated Dockerfile-alpine to 3.14 (#1722)
  * Fix unable to upload to OneDrive Business Shared Folders due to API restricting quota information (#1725)
  * Add SystemD hardening (#1720)
  * Update INSTALL.md
  * Update minimum compiler versions to dmd-2.087.0 and ldc-1.17.0 (#1724)
  * Release 2.4.15 Dev Prep (#1723)
  * Release files for 2.4.14 (#1719)
* Fri Dec 31 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.4.15
  * Add SystemD hardening (#1720)
  * Updated Dockerfile-alpine to use Apline 3.14 (#1722)
  * Update minimum compiler versions to dmd-2.087.0 and ldc-1.17.0
    (#1724)
  * Fix unable to upload to OneDrive Business Shared Folders due to
  * API restricting quota information (#1725)
  * Add --operation-timeout argument (#1759)
  * Update fixing edge case with OneDrive Personal Shared Folders
    and --resync --upload-only (#1762)
  * Updated documentation (various)
- Apply dmd and ldc minimum version requirements to spec
- Remove harden_onedrive.service.patch and
  harden_onedrive@.service.patch: applied upstream
* Wed Nov 24 2021 egotthold@suse.com
- Update to version 2.4.14
  https://github.com/abraunegg/onedrive/releases/tag/v2.4.14
- When using --logout there is no reauth performed as before, to login
  again just use the same command as on first run
- Enable notifications
* Wed Nov 17 2021 Lukas Müller <expeehaa@outlook.com>
- Weaken systemd service hardening to make services start again.
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_onedrive.service.patch
  * harden_onedrive@.service.patch
* Thu Jul 15 2021 egotthold@suse.com
- Update to version 2.4.13:
  https://github.com/abraunegg/onedrive/releases/tag/v2.4.13
- Removed: dmd-20970-support.patch
  Patch was included upstream and thus removed
* Sun Jun 27 2021 Boris Manojlovic <boris@steki.net>
- add patch for new dmd (from master merged patch)
  Support DMD 2.097.0 as compiler #1505 dmd-20970-support.patch
* Wed Jun  2 2021 egotthold@suse.com
- Update to version 2.4.12:
  https://github.com/abraunegg/onedrive/releases/tag/v2.4.12
* Wed Apr  7 2021 egotthold@suse.com
- Update to version 2.4.11:
  https://github.com/abraunegg/onedrive/releases/tag/v2.4.11
* Mon Mar  1 2021 egotthold@suse.com
- Update to version 2.4.10:
  * Release files for 2.4.10 (#1283)
  * Update INSTALL.md
  * Update INSTALL.md
  * Update INSTALL.md
  * Update INSTALL.md
  * Support sync_list matching full path root wildcard with exclusions to simplify sync_list configuration (#1273)
  * Use correct path offset for sync_list exclusion matching (#1269)
  * Revert the config & logpath change and check correct input entry (#1270)
  * Update USAGE.md
  * Fix logging output when handing downloaded files (#1267)
  * Revert "Fix logging output when handing downloaded new files (#1265)"
  * Fix logging output when handing downloaded new files (#1265)
  * Dockerfile config for arm64 (#1259)
  * Correctly handle '~' when present in 'log_dir' configuration option (#1258)
  * Update README.md
  * Improve upload handling of files for SharePoint sites (#1250)
  * Adding TOC to USAGE.md (#1244)
  * Use correct driveId value to query for changes when using --single-directory (#1235)
  * Search all distinct drive id's rather than just default drive id for --get-file-link (#1230)
  * Rename Office365.md to SharePoint-Shared-Libraries.md (#1232)
  * Support new file maximum upload size of 250GB (#1233)
  * Fix alpine build so it uses the same alpine version (#1226)
  * Catch database assertion when item path cannot be calculated (#1217)
  * Update Docker.md
  * Add new config option to rate limit connection to OneDrive (#1210)
  * Add upload speed metrics when files are uploaded (#1209)
  * Release 2.4.10 Dev Prep (#1207)
  * Release files for 2.4.9 (#1204)
  * Fixed 2 typos in advanced-usage.md (#1201)
  * Fix application crash with --get-O365-drive-id when API response is restricted (#1198)
  * Fix Alpine Docker build (#1197)
  * Fix application crash when calculating the path length due to invalid UTF characters (#1193)
  * Add Docker environment variable to allow --logout for re-authentication (#1187)
  * Improve application startup when using --monitor when there is no network connection to the OneDrive API (#1188)
  * Fix typo in advanced-usage.md (#1181)
  * Fix crash when unable to read a local file due to file permissions (Issue #1178) (#1179)
  * Add debug log output for configured API URL's (#1177)
  * Remove duplicate code for error output functions and enhance error logging output (#1170)
  * Handle case where API provided deltaLink generates a further API error (#1175)
  * Release 2.4.9 Dev Prep (#1168)
* Tue Dec  1 2020 egotthold@suse.com
- Update to version 2.4.8:
  * Release files for 2.4.8 (#1167)
  * Fix broken link in manual (#1166)
  * Fix application crash in --monitor mode due to 'Failed to stat file' when setgid is used on a directory (#1157)
  * Check application_id before setting redirect URL when using specific Azure endpoints (#1165)
  * Fix logging output when authentication authorisation fails (#1156)
  * Update #1142 logging output handling (#1153)
  * Fix changing permissions on pre-existing local directories (#1152)
  * Corrected typo (#1151)
  * Use config set option for 'remove_source_files' and 'skip_dir_strict_match' rather than ignore (#1142)
  * Update sync.d
  * Update sync.d
  * Update sync.d
  * Update sync.d
  * catch folder creation errors due to file system permissions error
  * Update error catching and handling
  * Update onedrive.d
  * Fix download failure due to incorrect filesystem permissions
  * Update USAGE.md to clarify 'application_id' usage to utilise older 'skilion' application id (#1136)
  * Release 2.4.8 Dev Prep (#1134)
* Mon Nov  9 2020 hpj@urpla.net
- Update to version 2.4.7:
  * Release files for 2.4.7 (#1133)
  * Correctly set config directory permissions at first start (#1132)
  * Check if localModifiedTime >= item.mtime: avoid re-upload (#1131)
  * Merge contents of SQLite WAL file into main database file on sync completion (#1128)
  * Fix uploading data to shared business folders when using --upload-only (#1127)
  * Check the given local path in reverse order for a skip_dir match on --resync (#1125)
  * Check for the presence of .nosync when processing DB entries (#1124)
  * Update Docker.md
  * Update --list-shared-folders to only show folders (#1114)
  * Cleanup dryrun shm and wal files if they exist (#1121)
  * Configure specific File and Folder Permissions (#1108)
  * Added env variable to enable download-only mode in Docker (#1113)
  * Fix Business Shared Folder handling to process only Business Shared Folders (#1104)
  * Update bug_report.md
  * Update bug_report.md
  * Fix logging output for modification comparison source (#1103)
  * Add environment variable to allow easy HTTPS debug in docker (#1098)
  * Adding support for authentication w/ single tenant custom applications (#1094)
  * Update bug_report.md
  * Update INSTALL.md
  * Update debugging output for /delta changes available queries (#1089)
  * Allow config to specify a tenant id for non-multi-tenant applications (#1085)
  * Mention fish-completions-dir build option (#1084)
  * Release 2.4.7 Dev Prep (#1088)
- Update to version 2.4.6:
  * Release files for 2.4.6 (#1083)
  * Update USAGE.md
  * Handle deletion events for directories when inotify events are missing (#1082)
  * Fix typos and normalize product names (#1079)
  * Update bug_report.md
  * Fix uninitialised value error as reported by valgrind (#1075)
  * Handle deletion events when inotify events are missing (#1073)
  * Add notification to advise users when the client needs to be reauthenticated (#1046)
  * Update INSTALL.md
  * Update INSTALL.md
  * Update INSTALL.md
  * Implement Feature: Multiple skip_dir & skip_file configuration rules (#1068)
  * Update USAGE.md
  * Implement Feature: Support negative patterns in sync_list for fine grained exclusions (#1065)
  * Support wildcard within sync_list entries (#1063)
  * Implement Feature: Create shareable link (#1061)
  * Update INSTALL.md
  * Update USAGE.md
  * Update INSTALL.md
  * Handle removing child items on OneDrive when parent item responds with access denied (Issue #1041) (#1045)
  * Update USAGE.md
  * Remove 'Icon' check as no longer valid (#1038)
  * Update INSTALL.md
  * Update --single-directory path handling when path does not exist locally (#1031)
  * Flag when remaining free space is being restricted (#1029)
  * Update README.md
  * Release 2.4.6 Dev Prep (#1030)
* Sun Sep 27 2020 Enno Gotthold <egotthold@suse.com>
- Changed from obs_scm to tar_scm to unstuck legaldb
- Added:
  * onedrive-2.4.5.tar
- Removed:
  * onedrive-2.4.5.obscpio
  * onedrive-2.4.5.tar.gz
* Wed Sep 16 2020 egotthold@suse.com
- Add fish completition to specfile
- Update to version 2.4.5:
  * Release files for 2.4.5 (#1018)
  * Fix installation of fish, enable autoconf configure argument (#1016)
  * Release 2.4.5 Development Prep (#1017)
  * Release files for 2.4.4 (#1015)
  * Update --single-directory handling of parent path matching (#1014)
  * Update how available free space is tracked when uploading files to OneDrive (#1011)
  * Fix 'Skipping uploading this new file as parent path is not in the database' when uploading to a Personal Shared Folder (#1009)
  * Update Office365 / SharePoint site search query (#1006)
  * Check shared folder DB entries for matching skip_dir items (#1003)
  * Update Docker.md (#1002)
  * Update when 'Sync with OneDrive is ..' is outputted when in --monitor mode (#999)
  * Fix segfault when moving file when using --monitor (#997)
  * Improve --single-directory sync performance (#992)
  * Fish Tab Auto-completions (#991)
  * Update the 'Processing XXXX' output to display the full path (#987)
  * Increase maximum file size to 100GB (#989)
  * Resolve client 'hang' when attempting to sync a Unix pipe file (#985)
  * Update 'skip_dir' and 'skip_file' pattern matching and handling for --monitor (#986)
  * Update 'skip_dir' and 'skip_file' pattern matching and handling (Issue #982) (#983)
  * Update installation instructions for NixOS (#981)
  * Update docker md (#977)
  * Update Dockerfiles (#980)
  * Update bug_report.md
  * Release 2.4.4 Development Prep (#974)
* Wed Aug 19 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use LDC on non-x86 archs since DMD is x86 only
* Tue Jul  7 2020 Enno Gotthold <egotthold@suse.com>
- Enable notifications via configure switch
- Enable bash and zsh completitions via configure switch
* Tue Jul  7 2020 egotthold@suse.com
- Update to version 2.4.3:
  * Release files for 2.4.3 (#970)
  * Process OneDrive Personal Shared Folders only if account type is 'personal' (#972)
  * Update Docker.md (#971)
  * Update USAGE.md (#968)
  * Update README.md
  * Update BusinessSharedFolders.md
  * Implement OneDrive Business Shared Folders Support (Issue #459) (#473)
  * Simplify code for readability (#961)
  * Update documentation for --upload-only & --download-only to avoid ambiguity (#960)
  * Support comments in sync_list file (#958)
  * Implement support for National cloud deployments (Issue #937) (#938)
  * Update known-issues.md
  * Implement recursive deletion when Retention Policy is enabled (#955)
  * Fix segfault when moving folder outside the sync directory when using --monitor (#957)
  * Add openSUSE package installation option (#956)
  * Update Ubuntu packaging details (#954)
  * Update INSTALL.md
  * Handle a 'race' condition to process inotify events (#948)
  * Added support for loading system configs if there's no user config. (#914)
  * Perform initial sync at startup in monitor mode (#946)
  * Update message output for performFullItemScan or oneDriveFullScanTrigger (#945)
  * Update logfile output spacing (#944)
  * Check if symbolic link is relative to location path (#942)
  * Update INSTALL.md
  * Add inotify event debugging (#941)
  * Release 2.4.3 Dev Prep (#940)
* Mon Jun 15 2020 Enno Gotthold <egotthold@suse.com>
- Modified service file to exclude bad file
* Wed May 27 2020 dmacvicar@suse.com
- Update to version 2.4.2:
  * Release files for 2.4.2 (#933)
  * Update known-issues.md
  * Update logging output of skipped files (#932)
  * Strengthen data preservation checks & update how bypass preservation is set (#931)
  * Add developer option to display sync options (#924)
  * Add file validation for moved / renamed files (#929)
  * Add debugging output for retry wait time (#928)
  * Change monitor interval default to 300 seconds (#923)
  * Implement 'bypass_data_preservation' enhancement (Issue #824) (#831)
  * Remove double scan of OneDrive when using --monitor --resync at application startup (#920)
  * Resolve issues identified by Valgrind (#910)
  * Check if configuration file exists before trying to load it (#909)
  * Fix module std.digest.digest is deprecated (#916)
  * Update enforce statement for parent id database query (Issue #912) (#913)
  * Update README.md
  * Catch unhandled MonitorException when inotify throws an error (Issue #903) (#905)
  * Better handle out-of-space message (#907)
  * Release 2.4.2 Dev Prep (#904)
  * Release files for 2.4.1 (#883)
  * Update how './' is stripped from a path before check if excluded (Issue #901) (#902)
  * Update handling of fullScanRequired and syncListConfiguredFullScanOverride (Issue #896) (#899)
  * Update #658 & #865 handling as when to setOneDriveFullScanTrigger (Issue #896) (#898)
  * Fix assertion when attempting to compute complex path (Issue #890) (#891)
  * Update progress bar to be more accurate when downloading large files (#888)
  * Update known-issues.md (#889)
  * Catch unhandled curl exception on operationTimeout being exceeded (#886)
  * Fix Codacy issues (#881)
  * Move build-rpm-howto.md to docs directory (#880)
  * Update CentOS Dockerfile (Issue #878) (#879)
  * Update README.md
  * Update README.md
  * Implement resync in config option (Issue #874) (#875)
  * Add known-issues.md (#877)
  * Update USAGE.md
  * Update README.md
  * Update RPM spec file (Issue #871) (#873)
  * Differenciate between OneNote objects and other unsupported objects (#870)
  * Perform full scan of OneDrive when required to ensure consistent local state (Issue #865) (#867)
  * Update handling of folders that cannot be read if parent should be skipped (#866)
  * Update link to new microsoft documentation (#861)
  * Update skip_dotfiles handling of .folders when in monitor mode (#848)
  * Update error logging output to be consistent (#860)
  * Handle zero-byte modified files for OneDrive Business (#854)
  * Handle .nosync directive when downloading new files (Issue #827) (#842)
  * Update --single-directory handling for --dry-run and --resync (#856)
  * Fix Alpine automated builds on Docker (#855)
  * Update application output when using --dry-run and --resync and database is corrupt (Issue#844) (#845)
  * Handle renaming dotfiles to another dotfile when skip_dotfile=true in monitor mode (#843)
  * Escape parentheses from path or file names (#841)
  * Handle renaming files to a name starting with a dot when skip_dotfile=true (#838)
  * Release 2.4.1 Dev Prep (#839)
* Wed May 27 2020 Duncan Mac-Vicar <dmacvicar@suse.com>
- Update to 2.4.2:
  * Catch unhandled MonitorException when inotify throws an error (#905)
  * Better handle out-of-space message (#907)
  * Check if configuration file exists before trying to load it (#909)
  * Resolve issues identified by Valgrind (#910)
  * Update enforce statement for parent id database query (#913)
  * Fix module std.digest.digest is deprecated (#916)
  * Remove double scan of OneDrive when using --monitor --resync at application startup (#920)
  * Change monitor interval default to 300 seconds (#923)
  * Add developer option to display sync options (#924)
  * Add debugging output for retry wait time (#928)
  * Add file validation for moved / renamed files (#929)
  * Strengthen data preservation checks & update how bypass preservation is set (#931)
  * Update logging output of skipped files (#932)
- Changes from 2.4.1:
  * Update documentation files (various)
  * Handle renaming files to a name starting with a dot when skip_dotfile=true (#838)
  * Escape parentheses from path or file names (#841)
  * Handle renaming dotfiles to another dotfile when skip_dotfile=true in monitor mode (#843)
  * Update application output when using --dry-run and --resync and database is corrupt (#845)
  * Fix Alpine automated builds on Docker (#855)
  * Update --single-directory handling for --dry-run and --resync (#856)
  * Handle .nosync directive when downloading new files (#842)
  * Handle zero-byte modified files for OneDrive Business (#854)
  * Update error logging output to be consistent (#860)
  * Update skip_dotfiles handling of .folders when in monitor mode (#848)
  * Update link to new Microsoft documentation (#861)
  * Update handling of folders that cannot be read if parent should be skipped (#866)
  * Perform full scan of OneDrive when required to ensure consistent local state (#867)
  * Differentiate between OneNote objects and other unsupported objects (#870)
  * Update RPM sample spec file (#873)
  * Implement --resync in config option (#875)
  * Update CentOS Dockerfile (#879)
  * Fix Codacy reported issues (#881)
  * Catch unhandled curl exception on operationTimeout being exceeded (#886)
  * Validate that the download progress bar is working for large files (#888)
  * Fix assertion when attempting to compute complex path (#891)
  * Update #658 & #865 handling as when to setOneDriveFullScanTrigger (#898)
  * Update handling of fullScanRequired and syncListConfiguredFullScanOverride (#899)
  * Update how './' is stripped from a path before check if excluded via skip_dir (#902)
* Tue May  5 2020 Enno Gotthold <egotthold@suse.com>
- _service: Exclude the testfolder as it contains files not readable
- Specfile: Change logrotate Require to Recommends
* Thu Apr 23 2020 Boris Manojlovic <boris@steki.net>
- corrected spec file: moved configure macro into build section
* Wed Apr 22 2020 Boris Manojlovic <boris@steki.net>
- updated spec file with license and documentation fixes
- removed redundant tar.gz file
- changed _service to buildtime
* Thu Apr 16 2020 Enno Gotthold <egotthold@suse.com>
- Changed the service & spec file so updates are done easier.
* Thu Apr 16 2020 egotthold@suse.com
- Update to version 2.4.0:
  * Release files for 2.4.0 (#833)
  * Update client identifier and auth scopes (Issue #769) (#770)
  * Update INSTALL.md (#834)
  * Update INSTALL.md
  * Update regex parsing of response URI (#830)
  * Update error response handling for catching HTTP 429 responses - activityLimitReached (Issue #815) (#816)
  * Handle moving files into a skipped .folder when skip_dotfiles = true (#828)
  * Update logging output (Issue #818) (#819)
  * Update application output when just authorising application (Issue #820) (#821)
  * Update ldc installation repo for alpine (#814)
  * Always log when a file is skipped due to the item being invalid (Issue #811)
  * Update USAGE.md
  * Catch when OneDrive throws an error response on initialising (Issue #802) (#804)
  * Update INSTALL.md
  * Update file handling when a failed download has occured due to CTRL-C (#800)
  * Update completions to include the --force-http-2 option (#799)
  * Update USAGE.md to clarify path when setting up multiple daemons (#798)
  * Catch 429 HTTPS return code when query for oneDriveRootDetails fails (#796)
  * Dockerfile for Raspberry Pi / ARM (#789)
  * Update how the 'username' is determined from the running process for logfile naming (Issue #786) (#787)
  * Implement #699 - Perform skip_dir explicit match only (#768)
  * Add NixOS installation instructions (#785)
  * Implement #763 - Delete local files after sync (#767)
  * Fix Docker alpine by adding ldc-runtime to output build (#778)
  * Update INSTALL.md
  * Fix Office 365 file name in README (#766)
  * Update USAGE.md
  * Update README.md
  * Implement warning on big deletes to safeguard data on OneDrive (#621)
  * Update Dockerfile-alpine file to fix Docker build issue (#764)
  * Release-2.4.0-dev prep (#761)
  * Release files for 2.3.13 (#760)
  * Fix --dry-run output to be consistent when using --upload-only & --no-remote-delete (Issue #758)
  * Change synclist override flag to false as default when not using sync_list (#745)
  * Update INSTALL.md build instructions for CentOS platforms (#754)
  * Update INSTALL.md with details of Linux packages (#752)
  * Update Ubuntu 16.x i386 instructions (#749)
  * Release-2.3.13-dev prep (#746)
* Wed Dec 25 2019 boris@steki.net
- Update to version 2.3.12:
  * Release files for 2.3.12 (#742)
  * Update INSTALL.md (#741)
  * Update Ubuntu i386 build instructions (#739)
  * Fix rebuilding of onedrive, but ensure version is properly updated (#731)
  * Fix where an item now out of scope should be flagged for local delete (#733)
  * Catch DNS resolution error (#730)
  * Check database for excluded sync_list items previously in scope (Issue #723) (#724)
  * Add debug message to when a message is sent to dbus or notification daemon (#728)
  * docker guide fixes, add multiple account setup instructions (#729)
  * Update Microsoft restriction and limitations (#725)
  * Retry session upload fragment when transient errors occur to prevent silent upload failure (#721)
  * Release 2.3.12-dev prep (#722)
  * Release files for 2.3.11 (#717)
  * Only monitor top level single directory + its children if using --single-directory (Issue #709)
  * Fix --monitor when used with --download-only (#708)
  * Catch a 412 response when moving files (Issue #706) (#707)
  * Fix unhandled monitor initialisation exception (Issue #704) (#705)
  * Revert "Fix unhandled monitor initialisation exception"
  * Fix unhandled monitor initialisation exception
  * Fix call from --monitor to observe --no-remote-delete (#703)
  * Fix 'Key not found: name' when computing skip_dir path (#701)
  * Reduce change scan impact of fix for #658 (#691)
  * Update skip_dir pattern matching when using wildcards (Issue #689) (#692)
  * Fix typo - retrySucess -> retrySuccess
  * Handle curl exceptions and timeouts better with backoff/retry logic (Issue #693) (#695)
  * Update JSON logging output (#696)
  * Remove unused and unexported SED variable in Makefile.in (#687)
  * Modify 'Processing X changes' output to be more reflective of actual activity (Issue #679) (#680)
  * Fix log output to be consistent
  * Fix typo - skip_list -> sync_list
  * Fix handling of skip_dir, skip_file & sync_list config options (#686)
  * Fixing typo in USAGE.md (#682)
  * Release 2.3.11-dev prep (#681)
  * Release files for 2.3.10 (#678)
  * Update config and usage.md (Issues #657, #675) (#676)
  * Make user-agent string a configuration option (#673)
  * Update entrypoint.sh with additional environment variables (#672)
  * Return remote name when 'case-insensitive match' (#670)
  * Fix crash when resume_upload file is not a valid JSON (#664)
  * Update OneDrive API status code 500 handling (#661)
  * Query for all changes if using sync_list file (#659)
  * Move logging of 'initialisation' to actually when the attempt to initialise is performed (#656)
  * Docker - Make --verbose optional based on environment variable (#651)
  * Fix downloading of files from OneDrive Personal Shared Folders (Issue #635) (#637)
  * Fix Ubuntu i386 / i686 install requirements (#652)
  * Revert "Make verbose logging output optional on Docker  (#638)"
  * Update documentation (#646)
  * Fix abnormal termination when no internet connection (#643)
  * Fix 'key not found: name' when checking if item was synced (#645)
  * Make verbose logging output optional on Docker  (#638)
  * Release 2.3.10-dev prep (#640)
  * Release files for 2.3.9 (#634)
  * Fix handling of 5xx responses from OneDrive when uploading via a session (Issue #632) (#631)
  * Add readme badges (#629)
  * Remove redundant logging output (#627)
  * Detect the need for --resync when config changes (#617)
  * Add additional JSON object validation (#623)
  * Fix unhandled error exceptions that cause application to exit / crash when uploading files (Issue #624) (#625)
  * Change minimum version of LDC to v1.12.0 (#626)
  * Remove double logging output for a OneDrive 412 error (#622)
  * Catch a 403 Forbidden exception when querying Sharepoint Library Names (#620)
  * Update for 2.3.9-dev (#618)
  * Release files for 2.3.8 (#614)
  * Implement --get-file-link (#612)
  * Update README.md
  * Catch error when creating sync dir fails (#608)
  * Add a check to handle moving items out of sync scope & delete locally if true (#604)
  * Resolve file / folder upload issues (Issue #598) (#602)
  * Update onedrive_service.sh
  * Add back CentOS 6 install & uninstall to Makefile (#601)
  * Update USAGE.md
  * Update USAGE.md
  * Update Sharepoint modified file handling for files > 4Mb in size (#594)
  * Add date tag on docker.hub (#584)
  * Update USAGE.md (#588)
  * Update Sharepoint Document Library modified file handling (#590)
  * Add explicit check for hashes being returned from OneDrive (Issue #591) (#592)
  * Update INSTALL.md (#589)
  * Fix hidden directories in 'root' from having prefix removed (#586)
  * Fix docker build error on stretch (#582)
  * Fix entrypoint.sh to work with "sudo docker run" (#581)
  * Update entrypoint.sh (#579)
  * Remove -d shorthand for --download-only (#577)
  * Update INSTALL.md
  * Update INSTALL.md
  * Update LDC to v1.16.0 (#574)
  * Update bug_report.md
  * Change unauthorized-api exit code to 3 (Issue #567) (#572)
  * Fix unable to download all files (Issue #563) (#568)
  * Update for 2.3.8-dev (#570)
* Mon Jul  8 2019 boris@steki.net
- Update to version 1562145247.ed19175:
  * 
* Mon Jul  8 2019 boris@steki.net
- Update to version 2.3.7:
  * Update LDC to v1.16.0 (#574)
  * Update bug_report.md
  * Change unauthorized-api exit code to 3 (Issue #567) (#572)
  * Fix unable to download all files (Issue #563) (#568)
  * Update for 2.3.8-dev (#570)
  * Release files for 2.3.7 (#566)
  * Fix not all files being downloaded due to query failure & false DB update (#564)
  * Update to 2.3.7-dev (#565)
  * Update release files for 2.3.6 (#562)
  * Update fix for Issue #555 (#559)
  * Add download size & hash check (Issue #558) (#560)
  * Handle OneDrive error response on creating upload session (#556)
  * Fixed some spelling/grammatical errors (#557)
  * Fix building without git available (#554)
  * Implement HTTP/2 downgrade by default (#549)
  * Add object check for json value (#551)
  * Update for new dev release (#548)
  * Release files for 2.3.5 (#546)
  * Check for supported version of D compiler
  * Update issue #540 fix (#543)
  * Update USAGE.md
  * Update USAGE.md (#544)
  * Size check should only be used if configured (Issue #540) (#541)
  * fix broken autoconf code for --enable-XXX options (#539)
  * get rid of forced root necessity during installation (#538)
  * Handle a directory in the sync_dir when no permission to access (Issue #532) (#536)
  * Update to v2.3.5-dev (#531)
  * Update files for release 2.3.4 (#530)
  * Fix building on docker hub and older install programs (#529)
  * Update gitignore (#528)
  * Install doc files without sub-directory (#527)
  * Rework directory layout and refactor MD files for readability (#523)
  * Support file based authorization (Issue: #524) (#525)
  * Update Dockerfile (#522)
  * fix docker entrypoint failures when gid is defined but not uid (#521)
  * implement skip_size (Issue #213) (#517)
  * Update missing cTag patch (Issue #512) (#515)
  * Handle OneDrive API response when cTag key is missing (Issue #512) (#513)
  * Enhance error message for curl CA SSL issue (Issue #507) (#508)
  * Check timestamp to ensure that latest timestamp is used when comparing OneDrive changes (Issue #505) (#506)
  * Update README.md
  * Catch a curl timeout exception (#499)
  * Check to ensure that file downloaded and is present locally before setting times (Issue #496)
  * Update sync.d (#493)
  * Update Makefile for RHEL/CentOS 7 systemd locations & fix uninstall of unit files (Issue #495) (#496)
  * Implement --sync-root-files when using a sync_list file (Issue #491) (#492)
  * Fix dry run reports "Deleting item from one drive" for remotely created file (Issue #489) (#490)
  * Better handling for initialisation errors (Issue #483) (#484)
  * Fix 'Local files not deleted' when using bad 'skip_file' entry (#480)
  * remove Makefile (#477)
  * Update Makefile (#475)
  * autoconf based build system (#287)
  * Update release files for 2.3.3 (#471)
  * Add logging as to why resume upload failed (Issue #468) (#470)
  * Update 'resume_upload' handling in the event of bad OneDrive response (Issue #468) (#469)
  * Update 'min_notif_changes' to 'min_notify_changes' (#467)
  * Add 'quota' check for valid value (#466)
  * Handle object error response from OneDrive (Issue #464) (#465)
  * config options for command line switches (#449)
  * Update onedrive.logrotate (#463)
  * Add completion support (Issue: #454) (#460)
  * Add debugging for --get-O365-drive-id (#462)
  * Update 'root' item identification handling (#457)
  * Add --upload-only check for sharepoint fix (Issue #452) (#453)
  * Implement more meaningful 5xx error responses (Issue #445) (#451)
  * Update release files for 2.3.2 (#448)
  * Issue #432 and #441 combined (#447)
  * Roll back to v2.3.1 (#446)
  * Resolve file creation loop when working directly in the synced folder with libreoffice (#442)
  * Reduce scanning of local filesystem needlessly every sync in monitor mode (#433)
  * fixes to the merge routine
  * move verbose check to first getopt to make it available early on
  * config directory management fixes
  * remove unnecessary code, cleanup
  * update log.verbose from options
  * remove work-around from previous versions
  * order getopt call options alphabetically
  * clean up, move help function
  * move more parts of the getopt calls into config module
  * config options: working version
  * more playing around
  * some playground
  * initial work on various config options for cmd line options
* Tue Mar 26 2019 boris@steki.net
- Update to version 2.3.1:
  * Update release files for 2.3.1 (#440)
  * Update Makefile (#439)
  * Update .travis-ci.sh (#435)
  * Update release files for 2.3.0 (#434)
  * Resolve high CPU usage when performing DB reads (#419)
  * Prevent use of --synchronize & --monitor together (#431)
  * Update 'skip_dir' handling to check against OneDrive new downloads (#427)
  * ignore a path containing multiple dirs in skip_dir
  * Fix JSONValue is not an object crash when a 5xx error is returned when uploading files (#426)
  * Declare version as phony (always outdated) target to guarantee update (#429)
* Mon Mar 18 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 2.2.6
  + Add support for install & uninstall on RHEL / CentOS 6.x (#353)
  + Add support for when notifications are enabled, display the number
    of OneDrive changes to process if any are found (#355)
  + Add 'config' option 'min_notif_changes' for minimum number
    of changes to notify on, default = 5 (#355)
  + Add additional Docker container builds utilising a smaller OS footprint (#369)
  + Add configurable interval of logging in monitor mode (#391)
  + Implement new CLI option --skip-dot-files to skip .files
    and .folders if option is used (#386)
  + Implement new CLI option --check-for-nosync to ignore folder
    when special file (.nosync) present (#390)
  + Implement new CLI option --dry-run (#337)
  + Resolve application crash when unable to delete remote folders
    when business retention policies are enabled (#338)
  + Resolve deprecation warning: loop index implicitly converted
    from size_t to int (#350)
  + Resolve warnings regarding 'bashisms' (#349)
  + Resolve handling of notification failure is dbus server has
    not started or available (#365)
  + Resolve handling of response JSON to ensure that 'id' key
    element is always checked for (#372)
  + Resolve excessive & needless logging in monitor mode (#373)
  + Resolve compiling with LDC on Alpine as musl lacks some standard interfaces (#369)
  + Resolve notification issues when offline and cannot act on changes (#385)
  + Resolve Docker entrypoint.sh to accept command line arguments (#387)
  + Resolve to create a new upload session on reinit (#379)
  + Resolve where on OneDrive query failure, default root
    and drive id is used if a response is not returned (#397)
  + Resolve Key not found: nextExpectedRanges when attempting
    session uploads and incorrect response is returned (#409)
  + Resolve application crash when re-using an authentication
    URI twice after previous --logout (#410)
  + Resolve creating a folder on a shared personal folder appears
    successful but returns a JSON error (#397)
  + Resolve to treat mv of new file as upload of mv target (#357)
  + Update Debian i386 build dependencies (#374)
  + Update handling of --get-O365-drive-id to print out all 'site names'
    that match the explicit search entry rather than just the last match (#354)
  + Update Docker readme & documentation (#363)
  + Update handling of validating local file permissions for new file uploads (#407)
  + Update --display-config to display sync_list if configured (#327)
  + Add --force-http-1.1 flag to downgrade any HTTP/2 curl operations to HTTP 1.1 protocol (#327)
  + Update handling of 'remote' folder designation as 'root' items (#328)
  + Add a check for 'id' key on metadata update to prevent
    'std.json.JSONException@std/json.d(494): Key not found: id' (#329)
  + Update handling of HTTP 412 - Precondition Failed errors (#329)
  + Fix items highlighted by codacy review (#332)
  + Ensure that remote deletes are handled correctly (#333)
  + Handle 'Item not found' exception when unable to query
    OneDrive 'root' for changes (#336)
  + Support building with ldc2 and usage of pkg-config for lib finding (#334)
  + Add handling for JSON response error when OneDrive API
    returns a 404 due to OneDrive API regression (#340)
  + OneDrive API Issue - Creating a folder on a shared personal folder appears
    successful but returns a JSON error (#339 / OneDrive/onedrive-api-docs#976)
* Mon Jan  7 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 2.2.4
* Tue Oct 23 2018 Hans-Peter Jansen <hpj@urpla.net>
- switch to significantly advanced abraunegg fork
- spec cleanup and adjustments
* Wed Apr 11 2018 boris@steki.net
- added patch crash when the delta link is expired
* Wed Feb 14 2018 boris@steki.net
- added released version 1.1.1
* Tue Jul  4 2017 boris@steki.net
- repack of git version as there are no more
  standard tagged releases
